==> qt-creator-opensource-src-4.12.1.zip: qt-creator-opensource-src-4.12.1/src/plugins/autotest/boost/boosttestframework.cpp <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "boosttestframework.h"
#include "boosttestconstants.h"
#include "boosttestsettings.h"
#include "boosttestsettingspage.h"
#include "boosttesttreeitem.h"
#include "boosttestparser.h"
#include "../testframeworkmanager.h"

namespace Autotest {
namespace Internal {

ITestParser *BoostTestFramework::createTestParser() const
{
    return new BoostTestParser;
}

TestTreeItem *BoostTestFramework::createRootNode() const
{
    return new BoostTestTreeItem(
                QCoreApplication::translate("BoostTestFramework",
                                            BoostTest::Constants::FRAMEWORK_SETTINGS_CATEGORY),
                QString(), TestTreeItem::Root);
}

const char *BoostTestFramework::name() const
{
    return BoostTest::Constants::FRAMEWORK_NAME;
}

unsigned BoostTestFramework::priority() const
{
    return BoostTest::Constants::FRAMEWORK_PRIORITY;
}

IFrameworkSettings *BoostTestFramework::createFrameworkSettings() const
{
    return new BoostTestSettings;
}

Core::IOptionsPage *BoostTestFramework::createSettingsPage(QSharedPointer<IFrameworkSettings> settings) const
{
    return new BoostTestSettingsPage(settings, settingsId());
}

bool BoostTestFramework::hasFrameworkSettings() const
{
    return true;
}

} // namespace Internal
} // namespace Autotest

==> qt-creator-opensource-src-4.13.0.zip: qt-creator-opensource-src-4.13.0/src/plugins/autotest/boost/boosttestframework.cpp <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "boosttestframework.h"
#include "boosttestconstants.h"
#include "boosttesttreeitem.h"
#include "boosttestparser.h"
#include "../testframeworkmanager.h"

namespace Autotest {
namespace Internal {

ITestParser *BoostTestFramework::createTestParser()
{
    return new BoostTestParser(this);
}

TestTreeItem *BoostTestFramework::createRootNode()
{
    return new BoostTestTreeItem(
                this,
                QCoreApplication::translate("BoostTestFramework",
                                            BoostTest::Constants::FRAMEWORK_SETTINGS_CATEGORY),
                QString(), TestTreeItem::Root);
}

const char *BoostTestFramework::name() const
{
    return BoostTest::Constants::FRAMEWORK_NAME;
}

unsigned BoostTestFramework::priority() const
{
    return BoostTest::Constants::FRAMEWORK_PRIORITY;
}

} // namespace Internal
} // namespace Autotest
